Raised by histogram constructors when buckets are invalid i.e. not sorted in increasing order or generator spec is unknown.
Summary
Functions
Callback implementation for Exception.message/1.
Functions
Callback implementation for Exception.message/1.