Raised when one tries to create metric in registry with name it already exists.
Summary
Functions
Callback implementation for Exception.message/1.
Functions
Callback implementation for Exception.message/1.
Raised when one tries to create metric in registry with name it already exists.
Callback implementation for Exception.message/1.
Callback implementation for Exception.message/1.