Raised by histogram constructors when buckets can't be found in spec, or found value is empty list.
Summary
Functions
Callback implementation for Exception.message/1.
Functions
Callback implementation for Exception.message/1.
Raised by histogram constructors when buckets can't be found in spec, or found value is empty list.
Callback implementation for Exception.message/1.
Callback implementation for Exception.message/1.